# The Cyral CLI Tool

Use this tool to obtain credentials for accessing a data repo via the Cyral sidecar.

**Note 1** This tool does not work with Cyral versions before 3.0. If you are using an
older version of Cyral, please use the [gimme-db-token](https://pypi.org/project/cyral-gimme-db-token/)
tool instead.

**Note 2** Use version 1.x of this tool for Cyral version 3.X and version 2.x for Cyral version 4.X and greater.

---
